@@ -3,9 +3,10 @@
 initResourcePaths <- function() {
   if (is.null(.global$loaded)) {
     shiny::addResourcePath(
-      prefix = 'shinyAce',
-      directoryPath = system.file('www', package='shinyAce'))
+      prefix = "shinyAce",
+      directoryPath = system.file("www", package = "shinyAce")
+    )
     .global$loaded <- TRUE
   }
   HTML("")
-}
\ No newline at end of file
+}
